@@ -22,9 +22,10 @@ from loguru import logger
 from starlette.applications import Starlette
 from starlette.datastructures import FormData as FormData
 from starlette.requests import Request as StarletteRequest
-from starlette.responses import JSONResponse, Response, StreamingResponse
+from starlette.responses import FileResponse, JSONResponse, Response, StreamingResponse
 from starlette.routing import Route, WebSocketRoute
-from starlette.websockets import WebSocket
+from starlette.staticfiles import StaticFiles
+from starlette.websockets import WebSocket, WebSocketDisconnect
 from yarl import URL
 
 from satori.config import WebhookInfo
@@ -103,11 +104,11 @@ class Server(Service, RouterMixin):
         self.routes = {}
         self.webhooks = webhooks or []
         self._tempdir = TemporaryDirectory()
-        self.proxy_url_mapping = {}
         self._sequence = 0
         self._event_cache = Deque(maxlen=100)
         self.stream_threshold = stream_threshold
         self.stream_chunk_size = stream_chunk_size
+        self.resources: dict[str, Path] = {}
         super().__init__()
 
     def apply(self, item: Provider | Router | Adapter):
@@ -115,15 +116,17 @@ class Server(Service, RouterMixin):
             item.ensure_server(self)
             self._adapters.append(item)
             self.providers.append(item)
-            self.proxy_url_mapping[item.id] = item.proxy_urls()
         elif isinstance(item, Provider):
             self.providers.append(item)
-            self.proxy_url_mapping[item.id] = item.proxy_urls()
         elif isinstance(item, Router):
             self.routers.append(item)
         else:
             raise TypeError(f"Unknown config type: {item}")
 
+    def mount(self, route_path: str, file: Path):
+        """在指定路径挂载静态文件"""
+        self.resources[route_path] = file
+
     async def event_callback(self, event: Event):
         event.id = self._sequence
         self._event_cache.append(event)
@@ -131,6 +134,8 @@ class Server(Service, RouterMixin):
         for connection in self.connections:
             try:
                 await connection.send({"op": Opcode.EVENT, "body": event.dump()})
+            except WebSocketDisconnect:
+                break
             except Exception as e:
                 print_exc()
                 logger.error(e)
@@ -141,8 +146,10 @@ class Server(Service, RouterMixin):
                     headers={
                         "Content-Type": "application/json",
                         "Authorization": f"Bearer {hook.token or ''}",
-                        "X-Platform": event.platform,
-                        "X-Self-ID": event.self_id,
+                        "X-Platform": event.platform_,
+                        "Satori-Platform": event.platform_,
+                        "X-Self-ID": event.self_id_,
+                        "Satori-Login-ID": event.self_id_,
                     },
                     json={"op": Opcode.EVENT, "body": event.dump()},
                 ) as resp:
@@ -191,19 +198,22 @@ class Server(Service, RouterMixin):
     async def admin_login_list_handler(self, request: StarletteRequest):
         logins = []
         for provider in self.providers:
-            logins.extend(await provider.get_logins())
+            _logins = await provider.get_logins()
+            for _login in _logins:
+                _login.proxy_urls.extend(provider.proxy_urls())
+            logins.extend(_logins)
         return JSONResponse(content=[lo.dump() for lo in logins])
 
     async def http_server_handler(self, request: StarletteRequest):
         if not self._adapters and not self.routes:
             return Response(status_code=404, content=request.path_params["method"])
         method = request.path_params["method"]
-        if "X-Platform" not in request.headers:
-            return Response(status_code=401, content="Missing X-Platform header")
-        platform = request.headers["X-Platform"]
-        if "X-Self-ID" not in request.headers:
-            return Response(status_code=401, content="Missing X-Self-ID header")
-        self_id = request.headers["X-Self-ID"]
+        if "X-Platform" not in request.headers and "Satori-Platform" not in request.headers:
+            return Response(status_code=401, content="Missing header X-Platform or Satori-Platform")
+        platform: str = request.headers.get("X-Platform") or request.headers.get("Satori-Platform")  # type: ignore
+        if "X-Self-ID" not in request.headers and "Satori-Login-ID" not in request.headers:
+            return Response(status_code=401, content="Missing header X-Self-ID or Satori-Login-ID")
+        self_id: str = request.headers.get("X-Self-ID") or request.headers.get("Satori-Login-ID")  # type: ignore
 
         for _router in self._adapters:
             if method not in _router.routes:
@@ -223,6 +233,8 @@ class Server(Service, RouterMixin):
         url = request.path_params["upload_url"]
         try:
             content = await self.download(url)
+            if isinstance(content, Path):
+                return FileResponse(path=content)
             # if content size > stream_limit, use streaming response
             if len(content) > self.stream_threshold:
 
@@ -251,17 +263,22 @@ class Server(Service, RouterMixin):
                 if inst == f"{self.id}:{id(self)}":
                     file = Path(self._tempdir.name) / filename
                     if file.exists():
-                        return file.read_bytes()
+                        return file
                 raise FileNotFoundError(f"{filename} not found")
-            platform = pr.netloc
-            _, self_id, path = pr.path.split("/", 2)
-            for provider in self.providers:
+        for provider in self.providers:
+            if pr.scheme == "upload":
+                platform = pr.netloc
+                _, self_id, path = pr.path.split("/", 2)
                 if provider.ensure(platform, self_id):
                     return await provider.download_uploaded(platform, self_id, path)
-        for provider in self.providers:
-            for proxy_url_pf in self.proxy_url_mapping[provider.id]:
-                if url.startswith(proxy_url_pf):
-                    return await provider.download_proxied(proxy_url_pf, url)
+
+            for proxy_url_pf in provider.proxy_urls():
+                if not url.startswith(proxy_url_pf):
+                    continue
+                resp = await provider.download_proxied(proxy_url_pf, url)
+                if resp is None:
+                    continue
+                return resp
         raise ValueError(f"Unknown proxy url: {url}")
 
     def get_local_file(self, url: str):
@@ -323,6 +340,8 @@ class Server(Service, RouterMixin):
                     ),
                 ]
             )
+            for path, file in self.resources.items():
+                app.mount(path, StaticFiles(directory=file.parent, html=file.suffix == ".html"))
             asgi_service.middleware.mounts[""] = app  # type: ignore
 
         async def event_task(_provider: Provider):
